summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNico Vertriest <nico.vertriest@qt.io>2017-08-14 12:26:01 +0200
committerNico Vertriest <nico.vertriest@qt.io>2017-08-21 10:14:00 +0000
commit58639dab0360add8ccb23ca96141113fedf39866 (patch)
tree21c39fd88f730ac6c625625a66b506e764336757
parent9d8c9ada161ad97634992c444196add0abb4f9d1 (diff)
Doc: add doc to undocumented methods qskyboxentity.cpp
Change-Id: I3056be52f9203fbd99a3e5c01de71d79bafd2298 Reviewed-by: Venugopal Shivashankar <Venugopal.Shivashankar@qt.io> Reviewed-by: Jędrzej Nowacki <jedrzej.nowacki@qt.io>
-rw-r--r--src/extras/defaults/qskyboxentity.cpp17
1 files changed, 16 insertions, 1 deletions
diff --git a/src/extras/defaults/qskyboxentity.cpp b/src/extras/defaults/qskyboxentity.cpp
index 3c7b0dd4e..202ba4fcb 100644
--- a/src/extras/defaults/qskyboxentity.cpp
+++ b/src/extras/defaults/qskyboxentity.cpp
@@ -256,7 +256,12 @@ void QSkyboxEntity::setBaseName(const QString &baseName)
}
}
/*!
- * Returns the base name.
+ \property QSkyboxEntity::baseName
+
+ Contains the base name of the Skybox.
+*/
+/*!
+ * Returns the base name of the Skybox.
*/
QString QSkyboxEntity::baseName() const
{
@@ -278,6 +283,11 @@ void QSkyboxEntity::setExtension(const QString &extension)
}
/*!
+ \property QSkyboxEntity::extension
+
+ Contains the extension of the Skybox.
+*/
+/*!
* Returns the extension
*/
QString QSkyboxEntity::extension() const
@@ -311,4 +321,9 @@ bool QSkyboxEntity::isGammaCorrectEnabled() const
} // namespace Qt3DExtras
+/*!
+ \property QSkyboxEntity::gammaCorrect
+
+ A boolean indicating whether gamma correction is enabled.
+*/
QT_END_NAMESPACE